<?php
/* config.inc
 *    PHP include script for:
 *      1) IP Aggregation configuration
 *
 *  Configuration for ip aggregation & provision of common functions.
 *
 * 2015-03-22 v2.0.1 changes for language inclusion + dir changes
 * 2015-03-17 v1.0   Started -AK (derived from rblconfig.php)
 *
 * TAB=3
 *
 * @category Net
 * @version $Id: config.php, v2.0.1 2015-03-22
 * @author Alex KEMP
 */
// configuration   items begin
// generic         items begin

	// server paths for this file + sub-directories
	// this config file should be within include/require path,
	// else many `require_once' may need changing
	define('CFG_PATH',
		'/home/htdocs/hosted/modem-help.co.uk/www/aggregator/');		// changeme! (full server dir path is best)

	define('CFG_CPU_NUM',		4 );											// changeme! number of server cpu (cores)
	define('CFG_PUB_NOT',		CFG_PATH		.'');							// changeme! non-public base-dir path
	define('CFG_PUB_PATH',		CFG_PATH		.'public/');				// changeme!     public base-dir path
	define('CFG_INC_DIR',		CFG_PUB_NOT	.'include/');				//           non-public include dir
	define('CFG_LANG_DIR',		CFG_PUB_NOT	.'lang/');					//           non-public language base-dir

	define('CFG_SITE_DESC',		'Dedicated Help on Modems');			// changeme! site desc for webpage
	define('CFG_SITE_NAME',		'Modem-Help');								// changeme! site name for webpage
	define('CFG_TIMEZONE',		'Europe/London');							// changeme! if necessary

	date_default_timezone_set( CFG_TIMEZONE );

// generic         items end
// AGG specific    items begin

	// file locations & other defines
	define('AGG_CONTEG',			CFG_INC_DIR .'Conteg.inc');			// content negotiation Class file
	define('AGG_TEMPLATE',		CFG_INC_DIR .'Template.inc');			// templating Class file

	// webpage defines
	define('A_INDEX',				'Modem-Help logo');						// changeme! `alt' text for logo
	define('L_INDEX',				'Modem-Help Forum Index');				// changeme! text for index link
	define('T_BODY_BGCOLOR',	'E5E5E5');									// change if desired
	define('T_BODY_TEXT',		'000000');									// change if desired
	define('T_BODY_LINK',		'006699');									// change if desired
	define('T_BODY_VLINK',		'5493B4');									// change if desired
	define('U_INDEX',
		'http://www.modem-help.lan/aggregator/public/');				// changeme! url-base for logo/index link
	define('U_FAVICON',			U_INDEX .'favicon.ico');				// changeme! url for favicon.ico
	define('U_LOGO',				U_INDEX .'images/logo.png');			// changeme! url for logo src
	define('U_STYLE',				U_INDEX .'style.css');					// changeme! url for stylesheet

	// following sent as header string with cURL requests
	define('AGG_REFERER',		U_INDEX);									// change if desired

// var      declarations begin

	$_LANG					= 'EN';												// default language
	$AGG_CURL				= FALSE;												// cURL resource
	$S_CONTENT_ENCODING	= 'utf-8';

// var      declarations end
// AGG specific    items end
// configuration   items end

// function declarations begin

	function agg_init() {
		// prepare for cURL
		if( !( $resource = @curl_init())) {
			trigger_error('curl_init(): could not initialise cURL.', E_USER_ERROR );
			return FALSE;
		}
		// following throws an error on my system
//		if( !@curl_setopt( $resource, CURLOPT_MUTE, TRUE )) {
//			trigger_error('curl_setopt(): could not set cURL option: CURLOPT_MUTE:=TRUE.', E_USER_ERROR );
//			return FALSE;
//		}
		if( !@curl_setopt( $resource, CURLOPT_REFERER, AGG_REFERER )) {
			trigger_error('curl_setopt(): could not set cURL option: CURLOPT_REFERER:='. AGG_REFERER .'.', E_USER_ERROR );
			return FALSE;
		}
		if( !@curl_setopt( $resource, CURLOPT_HEADER, FALSE )) {
			trigger_error('curl_setopt(): could not set cURL option: CURLOPT_HEADER:=FALSE.', E_USER_ERROR );
			return FALSE;
		}
		$version	= curl_version();
		$version	= $version['version'];
		if( !@curl_setopt( $resource, CURLOPT_USERAGENT, $version )) {
			trigger_error("curl_setopt(): could not set cURL option: CURLOPT_USERAGENT:='libcurl/$version'.", E_USER_ERROR );
			return FALSE;
		}
		if( !@curl_setopt( $resource, CURLOPT_RETURNTRANSFER, TRUE )) {
			trigger_error('curl_setopt(): could not set cURL option: CURLOPT_RETURNTRANSFER:=TRUE.', E_USER_ERROR );
			return FALSE;
		}
		// no longer than 1 second, thanks
		if( !@curl_setopt( $resource, CURLOPT_CONNECTTIMEOUT, 1 )) {
			trigger_error('curl_setopt(): could not set cURL option: CURLOPT_CONNECTTIMEOUT:=1.', E_USER_ERROR );
			return FALSE;
		}
		return $resource;
   }
	// cURL GET
	function agg_get( $url ) {
		global $AGG_CURL;

		$str	= '';
		if( !$AGG_CURL ) {
			if( !( $AGG_CURL = agg_init())) {
				return FALSE;
			}
		}

		if( !@curl_setopt( $AGG_CURL, CURLOPT_URL, $url )) {
			trigger_error("curl_setopt(): could not set cURL option: CURLOPT_URL:='$url'.", E_USER_ERROR );
			return FALSE;
		}
		if(( $str = @curl_exec( $AGG_CURL )) === FALSE ) {
			// remote site failure
			if( curl_errno( $AGG_CURL )) {
				$err	= curl_error( $AGG_CURL );
			} else {
				$err	= 'curl_errno() did NOT offer any reason for failure.';
			}
			trigger_error("curl_exec(): URL='$url' failure: cURL stated: `$err`", E_USER_WARNING );
			return FALSE;
		} else if(( !is_string( $str )) or ( !strlen( $str ))) {
			// most likely an empty document, resulting in cURL returning TRUE
			trigger_error("curl_exec(): URL='$url' returned an empty document", E_USER_WARNING );
			return FALSE;
		}

		return $str;
   }

	function strTransform( $str ) {
		// a simple way to shaft many potential hacks
		// `chr(' is part of sql injection vulnerability
		$s = array('<?', '?>', 'chr(', '../');
		$r = array('Go away');
		return str_replace( $s, $r, $str );
	}

// function declarations end
// vi: shiftwidth=3 tabstop=3 et
?>
